==> haskell-heapsize-0.3.0.1-337.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-10Q360yxINE7d4ISR2MAyb
key:                  heapsize-0.3.0.1-10Q360yxINE7d4ISR2MAyb
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  53ebda84d836095195b8cb03f88151c7
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-10Q360yxINE7d4ISR2MAyb
depends:
    base-4.18.2.1 deepseq-1.4.8.1 exceptions-0.10.7 ghc-heap-9.6.6
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hashtables-1.4.2-GYcOHygQjk55KaHvD4feXc
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heapsize-0.3.0.1-338-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-BHt8xkyH7FOBgs4W3K3Se1
key:                  heapsize-0.3.0.1-BHt8xkyH7FOBgs4W3K3Se1
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  53827413d899f563fcf90af82e9a690a
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-BHt8xkyH7FOBgs4W3K3Se1
depends:
    base-4.18.2.1 deepseq-1.4.8.1 exceptions-0.10.7 ghc-heap-9.6.6
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hashtables-1.4.2-JIYntfUsYaQ63ueo7zjueU
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
